@@ -107,6 +107,7 @@ class ModelRecord(_Record):
             self.asset_bundle_sizes: Dict[str, int] = {"Windows": -1, "Darwin": -1, "Linux": -1}
             self.composite_object = False
             self.container_shapes: List[ContainerShape] = list()
+            self.affordance_points: List[Dict[str, float]] = list()
         else:
             self.wnid: str = data["wnid"]
             self.wcategory: str = data["wcategory"]
@@ -147,6 +148,9 @@ class ModelRecord(_Record):
                     else:
                         raise Exception(shape)
                     self.container_shapes.append(obj)
+            self.affordance_points: List[Dict[str, float]] = list()
+            if "affordance_points" in data:
+                self.affordance_points = data["affordance_points"]
 
 
 class MaterialRecord(_Record):
